diff --git a/scripts/licensecheck.pl b/scripts/licensecheck.pl
index 3d1ff2e..293186d 100755
--- a/scripts/licensecheck.pl
+++ b/scripts/licensecheck.pl
@@ -157,6 +157,14 @@ use warnings;
 use warnings    qw< FATAL  utf8     >;
 use Encode qw/decode/;
 
+my $dpkgipc = eval {require Dpkg::IPC;1});
+if ($dpkgipc) {
+    Dpkg::IPC->import(qw(spawn));
+} else {
+    # fallback for non-Debian system
+    require IPC::Run;
+    IPC::Run->import(qw(run));
+}
 use Dpkg::IPC qw(spawn);
 use Getopt::Long qw(:config gnu_getopt);
 use File::Basename;
@@ -337,11 +345,16 @@ while (@files) {
 
     # Encode::Guess does not work well, use good old file command to get file encoding
     my $mime;
-    spawn(exec => ['file', '--brief', '--mime', '--dereference', '--', $file],
-          to_string => \$mime,
-          error_to_file => '/dev/null',
-          nocheck => 1,
-          wait_child => 1);
+    if ($dpkgipc) {
+	spawn(exec => ['file', '--brief', '--mime', '--dereference', '--', $file],
+	      to_string => \$mime,
+	      error_to_file => '/dev/null',
+	      nocheck => 1,
+	      wait_child => 1);
+    } else {
+	# Fallback for the non-Debian system
+	run [qw(file --brief --mime --dereference), $file], \undef, \$mime;
+    }
     my $charset ;
     if ($mime =~ m/; charset=((?!binary)(?!unknown)[\w-]+)/) {
 	$charset = $1;
